==> ibiz-model-8.1.0.304-sources.jar: net/ibizsys/model/dataentity/dr/PSDEDRDetailImpl.java <==
package net.ibizsys.model.dataentity.dr;



public class PSDEDRDetailImpl extends net.ibizsys.model.PSObjectImpl implements net.ibizsys.model.dataentity.dr.IPSDEDRDetail{

	public final static String ATTR_GETCAPPSLANGUAGERES = "getCapPSLanguageRes";
	public final static String ATTR_GETCAPTION = "caption";
	public final static String ATTR_GETCOUNTERID = "counterId";
	public final static String ATTR_GETDETAILTYPE = "detailType";
	public final static String ATTR_GETENABLEMODE = "enableMode";
	public final static String ATTR_GETORDERVALUE = "orderValue";
	public final static String ATTR_GETORIGINCAPTION = "originCaption";
	public final static String ATTR_GETPSDETREEID = "getPSDETreeId";
	public final static String ATTR_GETPSSYSIMAGE = "getPSSysImage";
	public final static String ATTR_GETTESTPSDEOPPRIV = "getTestPSDEOPPriv";
	private net.ibizsys.model.res.IPSLanguageRes cappslanguageres;

	public net.ibizsys.model.res.IPSLanguageRes getCapPSLanguageRes(){
		if(this.cappslanguageres != null) return this.cappslanguageres;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETCAPPSLANGUAGERES);
		if(value == null){
			return null;
		}
		this.cappslanguageres = getPSModelObject(net.ibizsys.model.res.IPSLanguageRes.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETCAPPSLANGUAGERES);
		return this.cappslanguageres;
	}

	public net.ibizsys.model.res.IPSLanguageRes getCapPSLanguageResMust(){
		net.ibizsys.model.res.IPSLanguageRes value = this.getCapPSLanguageRes();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定标题语言资源");}
		return value;
	}


	public java.lang.String getCaption(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETCAPTION);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getCounterId(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETCOUNTERID);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getDetailType(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETDETAILTYPE);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getEnableMode(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETENABLEMODE);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public int getOrderValue(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETORDERVALUE);
		if(value == null){
			return 0;
		}
		return value.asInt();
	}

	public java.lang.String getOriginCaption(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETORIGINCAPTION);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getPSDETreeId(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETPSDETREEID);
		if(value == null){
			return null;
		}
		return value.asText();
	}
	private net.ibizsys.model.res.IPSSysImage pssysimage;

	public net.ibizsys.model.res.IPSSysImage getPSSysImage(){
		if(this.pssysimage != null) return this.pssysimage;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETPSSYSIMAGE);
		if(value == null){
			return null;
		}
		this.pssysimage = getPSModelObject(net.ibizsys.model.res.IPSSysImage.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETPSSYSIMAGE);
		return this.pssysimage;
	}

	public net.ibizsys.model.res.IPSSysImage getPSSysImageMust(){
		net.ibizsys.model.res.IPSSysImage value = this.getPSSysImage();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定成员图标资源对象");}
		return value;
	}

	private net.ibizsys.model.dataentity.priv.IPSDEOPPriv testpsdeoppriv;

	public net.ibizsys.model.dataentity.priv.IPSDEOPPriv getTestPSDEOPPriv(){
		if(this.testpsdeoppriv != null) return this.testpsdeoppriv;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETTESTPSDEOPPRIV);
		if(value == null){
			return null;
		}
		this.testpsdeoppriv = getPSModelObject(net.ibizsys.model.dataentity.priv.IPSDEOPPriv.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETTESTPSDEOPPRIV);
		return this.testpsdeoppriv;
	}

	public net.ibizsys.model.dataentity.priv.IPSDEOPPriv getTestPSDEOPPrivMust(){
		net.ibizsys.model.dataentity.priv.IPSDEOPPriv value = this.getTestPSDEOPPriv();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定判断输出实体操作标识");}
		return value;
	}

}

==> ibiz-model-8.1.0.465-sources.jar: net/ibizsys/model/dataentity/dr/PSDEDRDetailImpl.java <==
package net.ibizsys.model.dataentity.dr;



public class PSDEDRDetailImpl extends net.ibizsys.model.PSObjectImpl implements net.ibizsys.model.dataentity.dr.IPSDEDRDetail{

	public final static String ATTR_GETCAPPSLANGUAGERES = "getCapPSLanguageRes";
	public final static String ATTR_GETCAPTION = "caption";
	public final static String ATTR_GETCOUNTERID = "counterId";
	public final static String ATTR_GETCOUNTERMODE = "counterMode";
	public final static String ATTR_GETDETAILTYPE = "detailType";
	public final static String ATTR_GETENABLEMODE = "enableMode";
	public final static String ATTR_GETORDERVALUE = "orderValue";
	public final static String ATTR_GETORIGINCAPTION = "originCaption";
	public final static String ATTR_GETPSDEDRITEM = "getPSDEDRItem";
	public final static String ATTR_GETPSSYSIMAGE = "getPSSysImage";
	public final static String ATTR_GETTESTPSDEOPPRIV = "getTestPSDEOPPriv";
	private net.ibizsys.model.res.IPSLanguageRes cappslanguageres;

	public net.ibizsys.model.res.IPSLanguageRes getCapPSLanguageRes(){
		if(this.cappslanguageres != null) return this.cappslanguageres;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETCAPPSLANGUAGERES);
		if(value == null){
			return null;
		}
		this.cappslanguageres = getPSModelObject(net.ibizsys.model.res.IPSLanguageRes.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETCAPPSLANGUAGERES);
		return this.cappslanguageres;
	}

	public net.ibizsys.model.res.IPSLanguageRes getCapPSLanguageResMust(){
		net.ibizsys.model.res.IPSLanguageRes value = this.getCapPSLanguageRes();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定标题语言资源");}
		return value;
	}


	public java.lang.String getCaption(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETCAPTION);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getCounterId(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETCOUNTERID);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public int getCounterMode(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETCOUNTERMODE);
		if(value == null){
			return 0;
		}
		return value.asInt();
	}

	public java.lang.String getDetailType(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETDETAILTYPE);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getEnableMode(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETENABLEMODE);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public int getOrderValue(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETORDERVALUE);
		if(value == null){
			return 0;
		}
		return value.asInt();
	}

	public java.lang.String getOriginCaption(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETORIGINCAPTION);
		if(value == null){
			return null;
		}
		return value.asText();
	}
	private net.ibizsys.model.dataentity.dr.IPSDEDRItem psdedritem;

	public net.ibizsys.model.dataentity.dr.IPSDEDRItem getPSDEDRItem(){
		if(this.psdedritem != null) return this.psdedritem;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETPSDEDRITEM);
		if(value == null){
			return null;
		}
		net.ibizsys.model.dataentity.IPSDataEntity ipsdataentity = getParentPSModelObject(net.ibizsys.model.dataentity.IPSDataEntity.class);
		this.psdedritem = ipsdataentity.getPSDEDRItem(value, false);
		return this.psdedritem;
	}

	public net.ibizsys.model.dataentity.dr.IPSDEDRItem getPSDEDRItemMust(){
		net.ibizsys.model.dataentity.dr.IPSDEDRItem value = this.getPSDEDRItem();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定关系界面项");}
		return value;
	}

	private net.ibizsys.model.res.IPSSysImage pssysimage;

	public net.ibizsys.model.res.IPSSysImage getPSSysImage(){
		if(this.pssysimage != null) return this.pssysimage;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETPSSYSIMAGE);
		if(value == null){
			return null;
		}
		this.pssysimage = getPSModelObject(net.ibizsys.model.res.IPSSysImage.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETPSSYSIMAGE);
		return this.pssysimage;
	}

	public net.ibizsys.model.res.IPSSysImage getPSSysImageMust(){
		net.ibizsys.model.res.IPSSysImage value = this.getPSSysImage();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定成员图标资源对象");}
		return value;
	}

	private net.ibizsys.model.dataentity.priv.IPSDEOPPriv testpsdeoppriv;

	public net.ibizsys.model.dataentity.priv.IPSDEOPPriv getTestPSDEOPPriv(){
		if(this.testpsdeoppriv != null) return this.testpsdeoppriv;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETTESTPSDEOPPRIV);
		if(value == null){
			return null;
		}
		this.testpsdeoppriv = getPSModelObject(net.ibizsys.model.dataentity.priv.IPSDEOPPriv.class, (com.fasterxml.jackson.databind.node.ObjectNode)value, ATTR_GETTESTPSDEOPPRIV);
		return this.testpsdeoppriv;
	}

	public net.ibizsys.model.dataentity.priv.IPSDEOPPriv getTestPSDEOPPrivMust(){
		net.ibizsys.model.dataentity.priv.IPSDEOPPriv value = this.getTestPSDEOPPriv();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定判断输出实体操作标识");}
		return value;
	}

}
